# GeoQuest

[![PyPI - Version](https://img.shields.io/pypi/v/geoquest.svg)](https://pypi.org/project/geoquest)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/geoquest.svg)](https://pypi.org/project/geoquest)

-----

## Search, Geocode, and Reverse-Geocode Locations

GeoQuest is a lightweight Python package that provides an easy-to-use interface for searching, geocoding, and reverse-geocoding locations. With support for various APIs (including
Nominatim), it's perfect for location-based services, address validation, and route planning.


## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [API Documentation](#api-documentation)
- [Contributing](#contributing)
- [License](#license)

## Features

* Search for locations by address or other criteria
* Geocode addresses into latitude/longitude pairs
* Reverse-geocode coordinates back into human-readable addresses
* Caching mechanism to improve performance and reduce API requests


## Installation

You can install GeoQuest using pip:
```console
pip install geoquest
```

## API Documentation

For a full list of available functions and their usage, please refer to the [API documentation](https://mohitshrestha.github.io/geoquest/).

## Contributing

If you'd like to contribute to GeoQuest or report any issues, feel free to open a pull request or issue on this repository.

## License

`GeoQuest` is distributed under the terms of the [MIT](https://github.com/mohitshrestha/geoquest/blob/main/LICENSE) license.

MIT License

Copyright (c) 2024-present Mohit Shrestha <contact@mohitshrestha.com.np>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
